import { Class, Query } from '@nestjs-query/core';
import { Repository, SelectQueryBuilder, ObjectLiteral } from 'typeorm';
import { RelationMetadata } from 'typeorm/metadata/RelationMetadata';
import { FilterQueryBuilder } from './filter-query.builder';
import { AbstractQueryBuilder } from './query-builder.abstract';
interface JoinCondition {
    leftHand: string;
    rightHand: string;
}
interface JoinColumn {
    target: Class<unknown> | string;
    alias: string;
    conditions: JoinCondition[];
}
declare type WhereCondition = {
    sql: string;
    params: ObjectLiteral;
};
declare type PrimaryKey = {
    databasePath: string;
    selectPath: string;
    propertyName: string;
};
interface RelationQuery<Relation, Entity> {
    from: Class<Relation>;
    fromAlias: string;
    fromPrimaryKeys: PrimaryKey[];
    entityIds: string[];
    entityIdSelects: string[];
    joins: JoinColumn[];
    whereCondition(entity: Entity, entityIndex: number): WhereCondition;
}
/**
 * @internal
 *
 * Class that will convert a Query into a `typeorm` Query Builder.
 */
export declare class RelationQueryBuilder<Entity, Relation> extends AbstractQueryBuilder<Entity> {
    readonly repo: Repository<Entity>;
    readonly relation: string;
    private relationMetadata;
    readonly filterQueryBuilder: FilterQueryBuilder<Relation>;
    readonly relationRepo: Repository<Relation>;
    constructor(repo: Repository<Entity>, relation: string);
    select(entity: Entity | Entity[], query: Query<Relation>): SelectQueryBuilder<Relation>;
    private applyRelationFilter;
    private createRelationSubQuery;
    private createRelationQueryBuilder;
    private get relationMeta();
    getManyToOneOrOneToOneOwnerMeta(relation: RelationMetadata): RelationQuery<Relation, Entity>;
    getOneToManyOrOneToOneNotOwnerMeta(relation: RelationMetadata): RelationQuery<Relation, Entity>;
    getManyToManyOwnerMeta(relation: RelationMetadata): RelationQuery<Relation, Entity>;
    getManyToManyNotOwnerMetadata(relation: RelationMetadata): RelationQuery<Relation, Entity>;
    private createEntityIdSelect;
    static isEntityIdCol(colName: string): boolean;
    static parseEntityIdFromName(colName: string): string;
    getRelationPrimaryKeysPropertyNameAndColumnsName(): {
        columnName: string;
        propertyName: string;
    }[];
}
export {};
